@@ -20,6 +20,7 @@ package Apache2::AMFLiteDetectionFilter;
   use Apache2::Log;
   use Apache2::Filter (); 
   use APR::Table (); 
+  #use LWP::Simple;
   use LWP::Simple qw($ua get);
   use Apache2::Const -compile => qw(OK REDIRECT DECLINED);
   use IO::Uncompress::Unzip qw(unzip $UnzipError) ;
@@ -32,7 +33,7 @@ package Apache2::AMFLiteDetectionFilter;
   # 
 
   use vars qw($VERSION);
-  $VERSION= "4.07";
+  $VERSION= "4.08";
   my $CommonLib = new Apache2::AMFCommonLib ();
   my %MobileArray;#=$CommonLib->getMobileArray;
   my %MobileTabletArray;
@@ -46,13 +47,17 @@ package Apache2::AMFLiteDetectionFilter;
   my $configTouchFile;
   my $checkVersion='true';
   my $mobilenable="false";
-  #http://master.dl.sourceforge.net//project/mobilefilter/litetabletdetection.config
-  my $hostName = "skylineservers.dl.sourceforge.net";
-  my $hostServer="http://".$hostName."/project/mobilefilter/AMFRepository/";
+  my $hostNames = "downloads.sourceforge.net,master.dl.sourceforge.net,skylineservers.dl.sourceforge.net,garr.dl.sourceforge.net,jaist.dl.sourceforge.net,netassist.dl.sourceforge.net,vorboss.dl.sourceforge.net";
+  my @hostName = split(/,/, $hostNames);
+  my $numberOfAvaiableHosts=@hostName;
+  my $correctHost=0;
+  my $correctHostName=$hostName[$correctHost];
+  my $hostServer="http://".$correctHostName."/project/mobilefilter/AMFRepository/";
   my $urlmobile=$hostServer."litemobiledetection.config";
   my $urlTablet=$hostServer."litetabletdetection.config";
   my $urlTouch=$hostServer."litetouchdetection.config";
   my $urlBot=$hostServer."litebotdetection.config";
+  my $forceBlockDownload="false";
   $CommonLib->printLog("---------------------------------------------------------------------------"); 
   $CommonLib->printLog("-------                 APACHE MOBILE FILTER V$VERSION                  -------");
   $CommonLib->printLog("------- support http://groups.google.com/group/amf-device-detection -------");
@@ -87,15 +92,28 @@ package Apache2::AMFLiteDetectionFilter;
   }
   if ($checkVersion eq 'true') {
 	$CommonLib->printLog("Check on apchemobilefilter.org if the installed AMF is the last version");  
-	my $url=$hostServer."amf.config";
-    $CommonLib->printLog("Try to download ".$url);
-	my $content = get ($url);
 	my $check_version=0;
-	if ($content) {
-          $content =~ s/\n//g;
-	  $check_version=$content;
-	}
-        if ($check_version > $VERSION && $check_version ne 0) {
+    while ($check_version == 0 && $correctHost < $numberOfAvaiableHosts) {
+      my $url=$hostServer."amf.config";
+      $CommonLib->printLog("Try to download ".$url);
+      my $content = get ($url);
+      if ($content) {
+            $content =~ s/\n//g;
+            $check_version=$content;
+      } else {
+            $correctHost++;
+            if ($hostName[$correctHost]) {
+                  $correctHostName=$hostName[$correctHost];
+                  $hostServer="http://".$correctHostName."/project/mobilefilter/AMFRepository/";
+            }
+      }
+    }
+    if ($correctHost==$numberOfAvaiableHosts) {
+       $forceBlockDownload="true";
+		$CommonLib->printLog("It's not possible to connect to internet");
+    }
+    
+    if ($check_version > $VERSION && $check_version ne 0) {
 	       $CommonLib->printLog("---------------------------------------------------------------------------");
 	       $CommonLib->printLog("-----           There is a new version of AMF V$check_version online             ----");
 	       $CommonLib->printLog("---------------------------------------------------------------------------");
@@ -132,9 +150,9 @@ package Apache2::AMFLiteDetectionFilter;
     }
     if ($ENV{AMFDownloadParamURL}) {
 	                        $downloadparamurl=$ENV{AMFDownloadParamURL};
-				$CommonLib->printLog("DownloadAMFParamURL is: $downloadparamurl");
+                            $CommonLib->printLog("DownloadAMFParamURL is: $downloadparamurl");
     }
-    if ($downloadparamurl eq 'true') {
+    if ($downloadparamurl eq 'true' && $forceBlockDownload eq "false") {
         &readMobileParamFromUrl;	
         &readTabletParamFromUrl;
         &readTouchParamFromUrl;
@@ -157,7 +175,7 @@ package Apache2::AMFLiteDetectionFilter;
                           $CommonLib->printLog("For access the device to fullbrowser set the link: <url>?$mobilenable=true");
      }
 sub readMobileParamFromUrl {
-		$CommonLib->printLog("Read data from ".$hostName);
+		$CommonLib->printLog("Read data from ".$correctHostName);
 		my $content = get ($urlmobile);
 		if ($content) {
 			$CommonLib->printLog("Download OK");
@@ -170,7 +188,7 @@ sub readMobileParamFromUrl {
 			    print MYFILE $content;
 			 close (MYFILE);
 		 } else {
-			$CommonLib->printLog("Download error ".$hostName);
+			$CommonLib->printLog("Download error ".$correctHostName);
 			$CommonLib->printLog("Try download previews version");
 			&readMobileParamFromFile;	
 		}
@@ -194,7 +212,7 @@ sub readMobileParamFromFile {
 		}
 }
 sub readTabletParamFromUrl {
-		$CommonLib->printLog("Read data for tablet detection from ".$hostName);
+		$CommonLib->printLog("Read data for tablet detection from ".$correctHostName);
 		my $content = get ($urlTablet);
 		if ($content) {
 			$CommonLib->printLog("Download OK");
@@ -207,7 +225,7 @@ sub readTabletParamFromUrl {
 			    print MYFILE $content;
 			 close (MYFILE);
 		 } else {
-			$CommonLib->printLog("Download error from ".$hostName);
+			$CommonLib->printLog("Download error from ".$correctHostName);
 			$CommonLib->printLog("Try download previews version");
 			&readTabletParamFromFile;	
 		}
@@ -231,7 +249,7 @@ sub readTabletParamFromFile {
 		}
 }
 sub readTouchParamFromUrl {
-		$CommonLib->printLog("Read data for touch detection from apachemobilefilter.org");
+		$CommonLib->printLog("Read data for touch detection from ".$correctHostName);
 		my $content = get ($urlTouch);
 		if ($content) {
 			$CommonLib->printLog("Download OK");
@@ -244,7 +262,7 @@ sub readTouchParamFromUrl {
 			    print MYFILE $content;
 			 close (MYFILE);
 		 } else {
-			$CommonLib->printLog("Download error from ".$hostName);
+			$CommonLib->printLog("Download error from ".$correctHostName);
 			$CommonLib->printLog("Try download previews version");
 			&readTouchParamFromFile;	
 		}
